@@ -135,7 +135,7 @@
 #' @export
 add.dates <- function(mn, sdev, depth, cc=1, above=1e-3, exx=50, normal=TRUE, normalise=TRUE, t.a=3, t.b=4, age.res=100, times=20, col=rgb(1,0,0,.5), border=rgb(1,0,0,.5), rotate.axes=FALSE, mirror=TRUE, up=TRUE, BCAD=FALSE)  {
   if(cc > 0)
-    cc <- rintcal::ccurve(cc)
+    cc <- ccurve(cc) # was rintcal::ccurve(cc) Sep 2024
   
   for(i in 1:length(mn)) {
     yrs <- seq(mn[i]-times*sdev[i], mn[i]+times*sdev[i], length=age.res)
